@@ -11,7 +11,8 @@ import unittest
 from katcp import Message, FailReply, AsyncReply
 from katcp.kattypes import request, inform, return_reply, send_reply,  \
                            Bool, Discrete, Float, Int, Lru, Timestamp, \
-                           Str, Struct, Regex, DiscreteMulti, TimestampOrNow
+                           Str, Struct, Regex, DiscreteMulti, TimestampOrNow, \
+                           StrictTimestamp
 
 class TestType(unittest.TestCase):
     def setUp(self):
@@ -73,11 +74,11 @@ class TestInt(TestType):
 class TestFloat(TestType):
 
     def setUp(self):
-        basic =  Int()
-        default = Int(default=11.0)
-        optional = Int(optional=True)
-        default_optional = Int(default=11.0, optional=True)
-        self.minmax = Int(min=5.0, max=6.0)
+        basic =  Float()
+        default = Float(default=11.0)
+        optional = Float(optional=True)
+        default_optional = Float(default=11.0, optional=True)
+        self.minmax = Float(min=5.0, max=6.0)
 
         self._pack = [
             (basic, 5.0, "5"),
@@ -232,6 +233,33 @@ class TestTimestamp(TestType):
         ]
 
 
+class TestStrictTimestamp(TestType):
+
+    def setUp(self):
+        basic =  StrictTimestamp()
+        default = StrictTimestamp(default=1235475793.03249)
+        optional = StrictTimestamp(optional=True)
+        default_optional = StrictTimestamp(default=1235475793.03249, optional=True)
+
+        self._pack = [
+            (basic, 1235475381.69669, "1235475381696.69"),
+            (basic, "a", ValueError),
+            (basic, None, ValueError),
+            (default, None, "1235475793032.49"),
+            (default_optional, None, "1235475793032.49"),
+            (optional, None, ValueError),
+        ]
+
+        self._unpack = [
+            (basic, "1235475381696", 1235475381.6960001),
+            (basic, "a", ValueError),
+            (basic, None, ValueError),
+            (default, None, 1235475793.03249),
+            (default_optional, None, 1235475793.03249),
+            (optional, None, None),
+        ]
+
+
 class TestTimestampOrNow(TestType):
 
     def setUp(self):
